@@ -1,10 +1,11 @@
 ## File Name: ml_mcmc.R
-## File Version: 0.497
+## File Version: 0.508
 
 ml_mcmc <- function( formula, data, iter=3000, burnin=500, print_iter=100,
     outcome="normal", nu0=NULL, s0=1, psi_nu0_list=NULL, psi_S0_list=NULL,
-    inits_lme4=TRUE, thresh_fac=5.8)
+    inits_lme4=FALSE, thresh_fac=5.8, ridge=1e-5)
 {
+    requireNamespace("coda")
     CALL <- match.call()
     s1 <- Sys.time()
 
@@ -76,6 +77,7 @@ ml_mcmc <- function( formula, data, iter=3000, burnin=500, print_iter=100,
     save_iter <- rep(-9, iter)
     save_iter[ seq(burnin+1, iter)] <- seq(1, iter-burnin ) - 1
     parnames0 <- unlist(parnames)
+
     ml_mcmc_fit_args <- list( y=y, X=X, Z_list=Z_list, beta=beta, Psi_list=Psi_list,
             sigma2=sigma2, alpha=alpha, u_list=u_list, idcluster_list=idcluster_list,
             onlyintercept_list=onlyintercept_list, ncluster_list=ncluster_list,
@@ -83,7 +85,8 @@ ml_mcmc <- function( formula, data, iter=3000, burnin=500, print_iter=100,
             psi_S0_list=psi_S0_list, est_sigma2=est_sigma2, est_probit=est_probit,
             parameter_index=parameter_index, est_parameter=est_parameter, npar=npar,
             iter=iter, save_iter=save_iter, verbose=verbose, print_iter=print_iter,
-            parnames0=parnames0, K=K, est_thresh=est_thresh, thresh_fac=thresh_fac )
+            parnames0=parnames0, K=K, est_thresh=est_thresh, thresh_fac=thresh_fac,
+            ridge=ridge)
 
     #*** MCMC estimation
     res <- do.call( what=ml_mcmc_fit, args=ml_mcmc_fit_args)
